@@ -44,12 +44,12 @@ sub save {
   my $self = shift;
   $self->saveZone;
   $self->saveInterface;
+  $self->saveFwNetworkPrivate;
   $self->saveAddress;
   $self->saveService;
   $self->saveRoute;
   $self->saveRule;
   $self->saveNat;
-  $self->saveFwNetworkPrivate;
 
   # 暂不支持
   # $self->saveSchedule;
@@ -69,7 +69,7 @@ sub saveZone {
   my $zoneExistsStatus = {new => {}, old => {}};
 
   # 遍历快照中的网络区域,写入 newZones 和 zoneExistsStatus
-  for my $zoneObj (values %{$self->{parser}{elements}{zone}}) {
+  for my $zoneObj (values $self->{parser}{elements}{zone}->%*) {
     my $zoneName = $zoneObj->{name};
     $newZones->{$zoneName} = undef;
     $zoneExistsStatus->{new}{$zoneName} = undef;
@@ -79,7 +79,7 @@ sub saveZone {
   $oldZones = $self->select(column => ['zone'], table => $tableName, where => {fw_id => $self->fwId})->all;
 
   # 寻找差量数据
-  for my $zoneName (map { $_->{zone} } @{$oldZones}) {
+  for my $zoneName (map { $_->{zone} } $oldZones->@*) {
 
     # 新旧zones均存在,则不是新的数据
     if (exists $newZones->{$zoneName}) {
@@ -91,16 +91,16 @@ sub saveZone {
   }
 
   # 根据网络区域状态更新数据
-  if (keys %{$zoneExistsStatus->{new}} > 0) {
+  if (keys $zoneExistsStatus->{new}->%* > 0) {
     my $sql    = "insert into $tableName (fw_id, zone) values (?, ?)";
-    my $params = [map { [$self->fwId, $_] } keys %{$zoneExistsStatus->{new}}];
+    my $params = [map { [$self->fwId, $_] } keys $zoneExistsStatus->{new}->%*];
     $self->batchExecute($params, $sql);
   }
 
   # 设置 state 为 0 代表停用状态
-  if (keys %{$zoneExistsStatus->{old}} > 0) {
+  if (keys $zoneExistsStatus->{old}->%* > 0) {
     my $sql    = "update $tableName set state = 1 where fw_id = ? and zone = ?";
-    my $params = [map { [$self->fwId, $_] } keys %{$zoneExistsStatus->{old}}];
+    my $params = [map { [$self->fwId, $_] } keys $zoneExistsStatus->{old}->%*];
     $self->batchExecute($params, $sql);
   }
 }
@@ -119,7 +119,7 @@ sub saveInterface {
   my $params;
 
   # 编辑快照解析到的接口对象
-  for my $interface (values %{$self->{parser}{elements}{interface}}) {
+  for my $interface (values $self->{parser}{elements}{interface}->%*) {
 
     # 构造 SQL VALUES
     my @ints;
@@ -151,7 +151,7 @@ sub saveInterface {
     push @ints, $interface->{interfaceType};
 
     # 将数据压入 $params
-    push @{$params}, \@ints;
+    push $params->@*, \@ints;
   }
   $self->batchExecute($params, $sql);
 }
@@ -174,7 +174,7 @@ sub saveNat {
   my $params;
 
   # 查询防火墙快照中的静态地址转换
-  for my $staticNat (values %{$self->{parser}{elements}{staticNat}}) {
+  for my $staticNat (values $self->{parser}{elements}{staticNat}->%*) {
 
     # 构造 SQL VALUES
     my @nat;
@@ -218,10 +218,10 @@ sub saveNat {
     push @nat, $staticNat->{config};
 
     # 将数据压入 params
-    push @{$params}, \@nat;
+    push $params->@*, \@nat;
   }
 
-  for my $dyNat (values %{$self->{parser}{elements}{dynamicNat}}) {
+  for my $dyNat (values $self->{parser}{elements}{dynamicNat}->%*) {
 
     # 构造 SQL VALUES
     my @nat;
@@ -281,7 +281,7 @@ sub saveNat {
     push @nat, $dyNat->{config};
 
     # 将数据压入 params
-    push @{$params}, \@nat;
+    push $params->@*, \@nat;
   }
   $self->batchExecute($params, $sql);
 }
@@ -303,7 +303,7 @@ sub saveRule {
   my $params;
 
   # 遍历解析到的防火墙策略
-  for my $rule (values %{$self->{parser}{elements}{rule}}) {
+  for my $rule (values $self->{parser}{elements}{rule}->%*) {
 
     # 构造 SQL VALUES
     my @rules;
@@ -323,9 +323,9 @@ sub saveRule {
     # to_zone
     push @rules, $rule->{toZone};
 
-    my @src = keys %{$rule->{srcAddressMembers}};
-    my @dst = keys %{$rule->{dstAddressMembers}};
-    my @srv = keys %{$rule->{serviceMembers}};
+    my @src = keys $rule->srcAddressMembers->%*;
+    my @dst = keys $rule->dstAddressMembers->%*;
+    my @srv = keys $rule->serviceMembers->%*;
 
     # source_addr
     push @rules, encode_json \@src;
@@ -356,13 +356,13 @@ sub saveRule {
     }
 
     # src_set
-    push @rules, encode_json {mins => $rule->{srcAddressGroup}{range}{mins}, maxs => $rule->{srcAddressGroup}{range}{maxs}};
+    push @rules, encode_json {mins => $rule->srcAddressGroup->range->mins, maxs => $rule->srcAddressGroup->range->maxs};
 
     # dst_set
-    push @rules, encode_json {mins => $rule->{dstAddressGroup}{range}{mins}, maxs => $rule->{dstAddressGroup}{range}{maxs}};
+    push @rules, encode_json {mins => $rule->dstAddressGroup->range->mins, maxs => $rule->dstAddressGroup->range->maxs};
 
     # srv_set
-    push @rules, encode_json {mins => $rule->{serviceGroup}{range}{mins}, maxs => $rule->{serviceGroup}{range}{maxs}};
+    push @rules, encode_json {mins => $rule->serviceGroup->range->mins, maxs => $rule->serviceGroup->range->maxs};
 
     # config
     push @rules, $rule->{content};
@@ -383,27 +383,27 @@ sub saveRule {
 
     # src_range
     my @src_range;
-    for (my $i = 0; $i < @{$rule->{srcAddressGroup}{range}{mins}}; $i++) {
-      push @src_range, "[" . $rule->{srcAddressGroup}{range}{mins}->[$i] . "," . $rule->{srcAddressGroup}{range}{maxs}->[$i] . "]";
+    for (my $i = 0; $i < $rule->srcAddressGroup->range->mins->@*; $i++) {
+      push @src_range, "[" . $rule->srcAddressGroup->range->mins->[$i] . "," . $rule->srcAddressGroup->range->maxs->[$i] . "]";
     }
     push @rules, \@src_range;
 
     # dst_range
     my @dst_range;
-    for (my $i = 0; $i < @{$rule->{dstAddressGroup}{range}->{mins}}; $i++) {
-      push @dst_range, "[" . $rule->{dstAddressGroup}{range}{mins}->[$i] . "," . $rule->{dstAddressGroup}{range}{maxs}->[$i] . "]";
+    for (my $i = 0; $i < $rule->dstAddressGroup->range->mins->@*; $i++) {
+      push @dst_range, "[" . $rule->dstAddressGroup->range->mins->[$i] . "," . $rule->dstAddressGroup->range->maxs->[$i] . "]";
     }
     push @rules, \@dst_range;
 
     # srv_range
     my @srv_range;
-    for (my $i = 0; $i < @{$rule->{serviceGroup}{range}{mins}}; $i++) {
-      push @srv_range, "[" . $rule->{serviceGroup}{range}{mins}->[$i] . "," . $rule->{serviceGroup}{range}{maxs}->[$i] . "]";
+    for (my $i = 0; $i < $rule->serviceGroup->range->mins->@*; $i++) {
+      push @srv_range, "[" . $rule->serviceGroup->range->mins->[$i] . "," . $rule->serviceGroup->range->maxs->[$i] . "]";
     }
     push @rules, \@srv_range;
 
     # 将数据压入 params
-    push @{$params}, \@rules;
+    push $params->@*, \@rules;
   }
   $self->batchExecute($params, $sql);
 }
@@ -425,7 +425,7 @@ sub saveRoute {
   my $params;
 
   # 遍历解析到的路由条目
-  for my $route (values %{$self->{parser}{elements}{route}}) {
+  for my $route (values $self->{parser}{elements}{route}->%*) {
 
     # 构造 SQL VALUES
     my @route;
@@ -443,7 +443,7 @@ sub saveRoute {
     push @route, $route->{nextHop};
 
     # network_range
-    push @route, encode_json {mins => $route->{range}{mins}, maxs => $route->{range}{maxs}};
+    push @route, encode_json {maxs => $route->range->maxs, mins => $route->range->mins,};
 
     # distance
     push @route, $route->{distance};
@@ -468,7 +468,7 @@ sub saveRoute {
       $hash{srcInterface} = $route->{srcInterface} if defined $route->{srcInterface};
 
       # 路由关联 srcRange
-      $hash{srcRange} = {mins => $route->{srcRange}{mins}, maxs => $route->{srcRange}{maxs}} if defined $route->{srcRange};
+      $hash{srcRange} = {mins => $route->srcRange->mins, maxs => $route->srcRange->maxs} if defined $route->{srcRange};
 
       # 路由关联 routeInstance
       $hash{routeInstance} = $route->{routeInstance} if defined $route->{routeInstance};
@@ -480,13 +480,13 @@ sub saveRoute {
 
     # network_set
     my @network_set;
-    for (my $i = 0; $i < @{mins => $route->{range}{mins},}; $i++) {
-      push @network_set, "[" . $route->{range}{mins}->[$i] . "," . $route->{range}{maxs}->[$i] . "]";
+    for (my $i = 0; $i < $route->range->mins->@*; $i++) {
+      push @network_set, "[" . $route->range->mins->[$i] . "," . $route->range->maxs->[$i] . "]";
     }
     push @route, \@network_set;
 
     # 将数据压入 params
-    push @{$params}, \@route;
+    push $params->@*, \@route;
   }
   $self->batchExecute($params, $sql);
 }
@@ -508,7 +508,7 @@ sub saveService {
   my $params;
 
   # 遍历解析到的服务端口对象
-  for my $serv (values %{$self->{parser}{elements}{service}}) {
+  for my $serv (values $self->{parser}{elements}{service}->%*) {
 
     # 构造 SQL VALUES
     my @serv;
@@ -526,17 +526,17 @@ sub saveService {
     push @serv, $serv->{config};
 
     # service_set
-    push @serv, encode_json {mins => $serv->{range}{mins}, maxs => $serv->{range}{maxs}};
+    push @serv, encode_json {mins => $serv->range->mins, maxs => $serv->range->maxs};
 
     # service_range
     my @service_range;
-    for (my $i = 0; $i < @{$serv->{range}{mins}}; $i++) {
-      push @service_range, "[" . $serv->{range}{mins}->[$i] . "," . $serv->{range}{maxs}->[$i] . "]";
+    for (my $i = 0; $i < $serv->range->mins->@*; $i++) {
+      push @service_range, "[" . $serv->range->mins->[$i] . "," . $serv->range->maxs->[$i] . "]";
     }
     push @serv, \@service_range;
 
     # 将数据压入 $params
-    push @{$params}, \@serv;
+    push $params->@*, \@serv;
   }
   $self->batchExecute($params, $sql);
 }
@@ -558,7 +558,7 @@ sub saveAddress {
   my $params;
 
   # 遍历解析到的地址对象
-  for my $addr (values %{$self->{parser}{elements}{address}}) {
+  for my $addr (values $self->{parser}{elements}{address}->%*) {
 
     # 构造 SQL VALUES
     my @addr;
@@ -576,12 +576,12 @@ sub saveAddress {
     push @addr, $addr->{config};
 
     # address_set
-    push @addr, encode_json {mins => $addr->{range}{mins}, maxs => $addr->{range}{maxs}};
+    push @addr, encode_json {mins => $addr->range->mins, maxs => $addr->range->maxs};
 
     # address_range
     my @address_range;
-    for (my $i = 0; $i < @{$addr->{range}{mins}}; $i++) {
-      push @address_range, "[" . $addr->{range}{mins}->[$i] . "," . $addr->{range}{maxs}->[$i] . "]";
+    for (my $i = 0; $i < $addr->range->mins->@*; $i++) {
+      push @address_range, "[" . $addr->range->mins->[$i] . "," . $addr->range->maxs->[$i] . "]";
     }
     push @addr, \@address_range;
 
@@ -589,11 +589,11 @@ sub saveAddress {
     push @addr, encode_json {zone => $addr->{zone}};
 
     # 压入数据到 $params
-    push @{$params}, \@addr;
+    push $params->@*, \@addr;
   }
 
   # 遍历地址组对象
-  for my $addrG (values %{$self->{parser}{elements}{addressGroup}}) {
+  for my $addrG (values $self->{parser}{elements}{addressGroup}->%*) {
 
     # 构造 SQL VALUES
     my @addr;
@@ -611,12 +611,12 @@ sub saveAddress {
     push @addr, $addrG->{config};
 
     # address_set
-    push @addr, encode_json {mins => $addrG->{range}{mins}, maxs => $addrG->{range}{maxs}};
+    push @addr, encode_json {mins => $addrG->range->mins, maxs => $addrG->range->maxs};
 
     # address_range
     my @address_range;
-    for (my $i = 0; $i < @{$addrG->{range}{mins}}; $i++) {
-      push @address_range, "[" . $addrG->{range}{mins}->[$i] . "," . $addrG->{range}{maxs}->[$i] . "]";
+    for (my $i = 0; $i < $addrG->range->mins->@*; $i++) {
+      push @address_range, "[" . $addrG->range->mins->[$i] . "," . $addrG->range->maxs->[$i] . "]";
     }
     push @addr, \@address_range;
 
@@ -624,139 +624,11 @@ sub saveAddress {
     push @addr, encode_json {zone => $addrG->{zone}};
 
     # 将数据压入 $params
-    push @{$params}, \@addr;
+    push $params->@*, \@addr;
   }
   $self->batchExecute($params, $sql);
 }
 
-#------------------------------------------------------------------------------
-# updateNetwork 抽象批量更新大网、私网接口
-#------------------------------------------------------------------------------
-sub updateNetwork {
-  my ($self, $zones, @tables) = @_;
-
-  # 如果传入的非哈希引用则自动修正
-  confess "网络区域必须是哈希引用"  if not ref $zones eq 'HASH' || not defined $zones;
-  confess "必须提供至少一个表单数据" if scalar @tables == 0;
-
-  # 遍历表单批量更新数据
-  foreach my $table (@tables) {
-
-    # 异常拦截
-    confess "数据表不匹配，请整体填写" if $table !~ /fw_network_main|fw_network_private/i;
-
-    # 定义 SQL 语句
-    my $sql = "insert into $table (fw_id,zone,addr_range,addr_min,addr_max) values(?,?,?,?,?)";
-
-    # 初始化变量
-    my $params;
-
-    # 插入数据之前删除历史数据
-    $self->delete(where => {fw_id => $self->fwId}, table => $table);
-
-    # 遍历防火墙网络区域
-    foreach my $zone (keys %{$zones}) {
-
-      # 这里的变量基于 Set 顺序一致
-      my $addrIprange = $zones->{$zone}{addrIpRange};
-      my $mins        = $zones->{$zone}{mins};
-      my $maxs        = $zones->{$zone}{maxs};
-
-      # COPY 复刻副本
-      my $copy_addrIprange = dclone $addrIprange;
-      my $copy_mins        = dclone $mins;
-      my $copy_maxs        = dclone $maxs;
-
-      # 遍历 addrIprange 数组
-      while (@{$copy_addrIprange}) {
-
-        # 初始化变量 @zone
-        my @zone;
-
-        # fw_id
-        push @zone, $self->fwId;
-
-        # zone
-        push @zone, $zone;
-
-        # addr_range
-        push @zone, pop @{$copy_addrIprange};
-
-        # addr_min
-        push @zone, pop @{$copy_mins};
-
-        # addr_max
-        push @zone, pop @{$copy_maxs};
-
-        # 将数据压入 params
-        push @{$params}, \@zone;
-      }
-    }
-
-    # 插入快照数据
-    $self->batchExecute($params, $sql);
-  }
-}
-
-#------------------------------------------------------------------------------
-# updateStaticNatToNetwork 抽象自动绑定 NAT 网段到大网数据表单
-#------------------------------------------------------------------------------
-sub updateStaticNatToNetwork {
-  my $self = shift;
-
-  # 初始化变量
-  my $params;
-  my $table = 'fw_network_main';
-
-  # 定义 SQL 语句
-  my $sql = "insert into $table (fw_id,zone,addr_range,addr_min,addr_max) values(?,?,?,?,?)";
-
-  # 查询防火墙快照中的静态地址转换
-  for my $staticNat (values %{$self->{parser}{elements}{staticNat}}) {
-
-    # 这里的变量基于 Set 顺序一致
-    my $mins = $staticNat->{natIpRange}{mins};
-    my $maxs = $staticNat->{natIpRange}{maxs};
-
-    # COPY 复刻副本 | 深度复刻、互不影响
-    my $copy_mins = dclone $mins;
-    my $copy_maxs = dclone $maxs;
-
-    # 遍历 $mins 数组
-    while (@{$copy_mins}) {
-
-      # 初始化变量 @network
-      my @network;
-
-      # 转换为 ipSet 集合 | 数据准备
-      my $min        = pop @{$copy_mins};
-      my $max        = pop @{$copy_maxs};
-      my $ipMin      = Firewall::Utils::Ip->new->changeIntToIp($min);
-      my $ipMax      = Firewall::Utils::Ip->new->changeIntToIp($max);
-      my $addr_range = $ipMin . "-" . $ipMax;
-
-      # fw_id | 数据填充阶段
-      push @network, $self->fwId;
-
-      # zone
-      push @network, $staticNat->{realZone};
-
-      # 填充 addr_range
-      push @network, $addr_range;
-
-      # addr_min
-      push @network, $min;
-
-      # addr_max
-      push @network, $max;
-
-      # 将数据压入 params
-      push @{$params}, \@network;
-    }
-    $self->batchExecute($params, $sql);
-  }
-}
-
 #------------------------------------------------------------------------------
 # saveFwNetworkPrivate 保存 parser 解析到的大网、私网对象
 #------------------------------------------------------------------------------
@@ -794,7 +666,7 @@ sub saveFwNetworkPrivate {
 
     # 遍历防火墙相关网络区域
     my (@protected, @unProtected, @unUse);
-    for my $zone (@{$zoneInfo}) {
+    for my $zone ($zoneInfo->@*) {
       if (defined $zone->{is_protected_zone}) {
         if ($zone->{is_protected_zone} == 1) {
           push @protected, $zone->{zone};
@@ -816,10 +688,11 @@ sub saveFwNetworkPrivate {
         my $zones = $self->{parser}{elements}{zone};
         $self->updateNetwork($zones, 'fw_network_private', 'fw_network_main');
       };
-      confess "批量更新防火墙大网、私网期间捕捉异常：$@" if !!$@;
+
+      # confess "批量更新防火墙大网、私网期间捕捉异常：$@" if defined $@;
     }
     else {
-      my $zoneIndex = $self->{parser}{elements}{zone};
+      my $zoneIndex = $self->{parser}->{elements}->{zone};
       my $protectedZone;
       my $unprotectedZone;
 
@@ -841,6 +714,134 @@ sub saveFwNetworkPrivate {
   }
 }
 
+#------------------------------------------------------------------------------
+# updateNetwork 抽象批量更新大网、私网接口
+#------------------------------------------------------------------------------
+sub updateNetwork {
+  my ($self, $zones, @tables) = @_;
+
+  # 如果传入的非哈希引用则自动修正
+  confess "网络区域必须是哈希引用"  if not ref $zones eq 'HASH' || not defined $zones;
+  confess "必须提供至少一个表单数据" if scalar @tables == 0;
+
+  # 遍历表单批量更新数据
+  foreach my $table (@tables) {
+
+    # 异常拦截
+    confess "数据表不匹配，请整体填写" if $table !~ /fw_network_main|fw_network_private/i;
+
+    # 定义 SQL 语句
+    my $sql = "insert into $table (fw_id,zone,addr_range,addr_min,addr_max) values(?,?,?,?,?)";
+
+    # 初始化变量
+    my $params;
+
+    # 插入数据之前删除历史数据
+    $self->delete(where => {fw_id => $self->fwId}, table => $table);
+
+    # 遍历防火墙网络区域
+    foreach my $zone (keys $zones->%*) {
+
+      # 这里的变量基于 Set 顺序一致
+      my $addrIprange = $zones->{$zone}->addrIpRange;
+      my $mins        = $zones->{$zone}->mins;
+      my $maxs        = $zones->{$zone}->maxs;
+
+      # COPY 复刻副本
+      my $copy_addrIprange = dclone $addrIprange;
+      my $copy_mins        = dclone $mins;
+      my $copy_maxs        = dclone $maxs;
+
+      # 遍历 addrIprange 数组
+      while ($copy_addrIprange->@*) {
+
+        # 初始化变量 @zone
+        my @zone;
+
+        # fw_id
+        push @zone, $self->fwId;
+
+        # zone
+        push @zone, $zone;
+
+        # addr_range
+        push @zone, pop $copy_addrIprange->@*;
+
+        # addr_min
+        push @zone, pop $copy_mins->@*;
+
+        # addr_max
+        push @zone, pop $copy_maxs->@*;
+
+        # 将数据压入 params
+        push $params->@*, \@zone;
+      }
+    }
+
+    # 插入快照数据
+    $self->batchExecute($params, $sql);
+  }
+}
+
+#------------------------------------------------------------------------------
+# updateStaticNatToNetwork 抽象自动绑定 NAT 网段到大网数据表单
+#------------------------------------------------------------------------------
+sub updateStaticNatToNetwork {
+  my $self = shift;
+
+  # 初始化变量
+  my $params;
+  my $table = 'fw_network_main';
+
+  # 定义 SQL 语句
+  my $sql = "insert into $table (fw_id,zone,addr_range,addr_min,addr_max) values(?,?,?,?,?)";
+
+  # 查询防火墙快照中的静态地址转换
+  for my $staticNat (values $self->{parser}{elements}{staticNat}->%*) {
+
+    # 这里的变量基于 Set 顺序一致
+    my $mins = $staticNat->natIpRange->mins;
+    my $maxs = $staticNat->natIpRange->maxs;
+
+    # COPY 复刻副本 | 深度复刻、互不影响
+    my $copy_mins = dclone $mins;
+    my $copy_maxs = dclone $maxs;
+
+    # 遍历 $mins 数组
+    while ($copy_mins->@*) {
+
+      # 初始化变量 @network
+      my @network;
+
+      # 转换为 ipSet 集合 | 数据准备
+      my $min        = pop $copy_mins->@*;
+      my $max        = pop $copy_maxs->@*;
+      my $ipMin      = Firewall::Utils::Ip->new->changeIntToIp($min);
+      my $ipMax      = Firewall::Utils::Ip->new->changeIntToIp($max);
+      my $addr_range = $ipMin . "-" . $ipMax;
+
+      # fw_id | 数据填充阶段
+      push @network, $self->fwId;
+
+      # zone
+      push @network, $staticNat->{realZone};
+
+      # 填充 addr_range
+      push @network, $addr_range;
+
+      # addr_min
+      push @network, $min;
+
+      # addr_max
+      push @network, $max;
+
+      # 将数据压入 params
+      push $params->@*, \@network;
+    }
+    $self->batchExecute($params, $sql);
+  }
+}
+
 #------------------------------------------------------------------------------
 # saveSchedule 保存 parser 解析到计划任务对象
 #------------------------------------------------------------------------------
