@@ -11,11 +11,6 @@ use namespace::autoclean;
 #------------------------------------------------------------------------------
 use Firewall::Config::Element::Service::Huawei;
 
-#------------------------------------------------------------------------------
-# 继承 Firewall::Config::Dao::PredefinedService::Role 方法属性
-#------------------------------------------------------------------------------
-with 'Firewall::Config::Dao::PredefinedService::Role';
-
 #------------------------------------------------------------------------------
 # 具体实现 _buildPreDefinedServiceTableName 方法，返回数据表
 #------------------------------------------------------------------------------
