@@ -3,15 +3,9 @@ package Firewall::Config::Dao::PredefinedService::Neteye;
 #------------------------------------------------------------------------------
 # 加载扩展模块
 #------------------------------------------------------------------------------
-use 5.016;
 use Moose;
 use namespace::autoclean;
 
-#------------------------------------------------------------------------------
-# 加载 Firewall::Config::Element::Service::Neteye 解析插件
-#------------------------------------------------------------------------------
-use Firewall::Config::Element::Service::Neteye;
-
 #------------------------------------------------------------------------------
 # 继承 Firewall::Config::Dao::PredefinedService::Role 方法属性
 #------------------------------------------------------------------------------
