@@ -6,11 +6,6 @@ package Firewall::Config::Dao::PredefinedService::PaloAlto;
 use Moose;
 use namespace::autoclean;
 
-#------------------------------------------------------------------------------
-# 加载 Firewall::Config::Element::Service::PaloAlto 解析插件
-#------------------------------------------------------------------------------
-use Firewall::Config::Element::Service::PaloAlto;
-
 #------------------------------------------------------------------------------
 # 继承 Firewall::Config::Dao::PredefinedService::Role 方法属性
 #------------------------------------------------------------------------------
